@@ -174,40 +174,43 @@ class COCO:
         :return: ids (int array)       : integer array of ann ids
 
         """
-
-        anns = []
-
-        if len(imgIds) != 0:
-            for img_id in imgIds:
-                anns.extend(self.img_ann_map[img_id])
-        else:
-            anns = self.dataset["annotations"]
-
-        # return early if no more filtering required
-        if (len(catIds) == 0) and (len(areaRng) == 0) and (iscrowd is None):
-            return [_ann["id"] for _ann in anns]
-
-        cat_ids = set(catIds)
-
-        if len(areaRng) == 0:
-            areaRng = [0, float("inf")]
-
         imgIds = imgIds if _isArrayLike(imgIds) else [imgIds]
         catIds = catIds if _isArrayLike(catIds) else [catIds]
 
-        if iscrowd is None:
-            iscrowd = False
+        check_area = len(areaRng) > 0
+        check_crowd = iscrowd is not None
+        check_cat = len(catIds) > 0
+        check_img = len(imgIds) > 0
 
-        ann_ids = [
-            _ann["id"]
-            for _ann in anns
-            if _ann["category_id"] in cat_ids
-            and _ann["area"] > areaRng[0]
-            and _ann["area"] < areaRng[1]
-            and int(_ann.get("iscrowd", 0)) == int(iscrowd)
-        ]
+        if not (check_area and check_crowd and check_cat and check_img):
+            anns = self.dataset["annotations"]
+        else:
+            anns = []
 
-        return ann_ids
+            if check_img:
+                for img_id in imgIds:
+                    anns.extend(self.img_ann_map[img_id])
+            else:
+                anns = self.dataset["annotations"]
+
+            if check_cat:
+                anns = [ann for ann in anns if ann["category_id"] in catIds]
+
+            if check_area:
+                areaRng = [0, float("inf")]
+
+                anns = [
+                    ann
+                    for ann in anns
+                    if ann["area"] > areaRng[0] and ann["area"] < areaRng[1]
+                ]
+
+            if check_crowd:
+                anns = [ann for ann in anns if ann["iscrowd"] == iscrowd]
+
+        ids = [ann["id"] for ann in anns]
+
+        return ids
 
     def getCatIds(self, catNms=[], supNms=[], catIds=[]):
         """Filtering parameters.
